@@ -214,22 +214,31 @@
     user-at-host))
 
 (defun riece-get-users-on-server (server-name)
-  (delq nil (mapcar (lambda (identity)
-		      (if (riece-user-p (riece-identity-prefix identity))
-			  identity))
-		    (riece-get-identities-on-server server-name))))
-
-(defun riece-get-identities-on-server (server-name)
   (riece-with-server-buffer server-name
     (let (identities)
       (mapatoms
-       (lambda (atom)
+       (lambda (user)
 	 (setq identities
-	       (cons (riece-make-identity (symbol-name atom) server-name)
+	       (cons (riece-make-identity (symbol-name user) server-name)
 		     identities)))
-       riece-obarray)
+       riece-user-obarray)
       identities)))
 
+(defun riece-get-channels-on-server (server-name)
+  (riece-with-server-buffer server-name
+    (let (identities)
+      (mapatoms
+       (lambda (channel)
+	 (setq identities
+	       (cons (riece-make-identity (symbol-name channel) server-name)
+		     identities)))
+       riece-channel-obarray)
+      identities)))
+
+(defun riece-get-identities-on-server (server-name)
+  (nconc (riece-get-channels-on-server server-name)
+	 (riece-get-users-on-server server-name)))
+
 (defun riece-check-channel-commands-are-usable (&optional channel)
    (unless riece-current-channel
      (error (substitute-command-keys
